.. fapistrano documentation master file, created by
   sphinx-quickstart on Mon Feb  1 10:33:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fapistrano's documentation!
======================================

Fapistrano is a remote server automation and deployment tool.
It can be easily used to rolling update your sites.

Fapistrano grows from several `fabric` tasks and inspired by capistrano.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   quick_start
   directory
   configuration
   cli
   plugin
   signals
   12factor

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

